//
// Copyright 2016 Pixar
//
// Licensed under the terms set forth in the LICENSE.txt file available at
// https://openusd.org/license.
//
#include "pxr/usdImaging/usdRiPxrImaging/tokens.h"

#include "pxr/base/tf/staticTokens.h"

#include "pxr/pxr.h"

PXR_NAMESPACE_OPEN_SCOPE

TF_DEFINE_PUBLIC_TOKENS(UsdRiPxrImagingTokens, USDRIPXRIMAGING_TOKENS);
TF_DEFINE_PUBLIC_TOKENS(
    UsdRiPxrImagingPrimTypeTokens, USDRIPXRIMAGING_PRIM_TYPE_TOKENS);

PXR_NAMESPACE_CLOSE_SCOPE
